<?php
/**
 * Retrieves and creates the wp-config.php file.
 *
 * The permissions for the base directory must allow for writing files in order
 * for the wp-config.php to be created using this page.
 *
 * @package WordPress
 * @subpackage Administration
 */

/**
 * We are installing.
 *
 * @package WordPress
 */
define('WP_INSTALLING', true);

/**
 * We are blissfully unaware of anything.
 */
define('WP_SETUP_CONFIG', true);

/**
 * Disable error reporting
 *
 * Set this to error_reporting( E_ALL ) or error_reporting( E_ALL | E_STRICT ) for debugging
 */
error_reporting(0);

/**#@+
 * These three defines are required to allow us to use require_wp_db() to load
 * the database class while being wp-content/db.php aware.
 * @ignore
 */
define('ABSPATH', dirname(dirname(__FILE__)).'/');
define('WPINC', 'wp-includes');
define('WP_CONTENT_DIR', ABSPATH . 'wp-content');
define('WP_DEBUG', false);
/**#@-*/

require_once(ABSPATH . WPINC . '/load.php');
require_once(ABSPATH . WPINC . '/compat.php');
require_once(ABSPATH . WPINC . '/functions.php');
require_once(ABSPATH . WPINC . '/class-wp-error.php');
require_once(ABSPATH . WPINC . '/version.php');

if (!file_exists(ABSPATH . 'wp-config-sample.php'))
	wp_die('Bedaŭrinde, mi bezonas dosieron wp-config. Bonvolu denove alŝuti tiun dosieron de via instalo de WordPress.');

$configFile = file(ABSPATH . 'wp-config-sample.php');

// Check if wp-config.php has been created
if (file_exists(ABSPATH . 'wp-config.php'))
	wp_die("<p>La dosiero 'wp-config.php' jam ekzistas. Se vi bezonas denove alĝustig iun el la agordoj en ĉi tiu dosiero, bonvolu unue forigi ĝin. Vi povas trovi <a href='install.php'>instali nun</a>.</p>");

// Check if wp-config.php exists above the root directory but is not part of another install
if (file_exists(ABSPATH . '../wp-config.php') && ! file_exists(ABSPATH . '../wp-settings.php'))
	wp_die("<p>La dosiero 'wp-config.php' jam ekzistas en nivelo supre de via WordPress-a instalo. Se vi bezonas denove alĝustigi iun agordon en ĉi tiu dosiero, bonvolu forigi ĝin unue. <a href='install.php'>instali nun</a>.</p>");

if ( version_compare( $required_php_version, phpversion(), '>' ) )
	wp_die( sprintf( /*WP_I18N_OLD_PHP*/'Via servilo uzas version %1$s de PHP sed WordPress bezonas almenaŭ version %2$s.'/*/WP_I18N_OLD_PHP*/, phpversion(), $required_php_version ) );

if ( !extension_loaded('mysql') && !file_exists(ABSPATH . 'wp-content/db.php') )
	wp_die( /*WP_I18N_OLD_MYSQL*/'Via instalo de PHP ŝajne ne havas la etendaĵon por MySQL kiun WordPress bezonas.'/*/WP_I18N_OLD_MYSQL*/ );

if (isset($_GET['step']))
	$step = $_GET['step'];
else
	$step = 0;

/**
 * Display setup wp-config.php file header.
 *
 * @ignore
 * @since 2.3.0
 * @package WordPress
 * @subpackage Installer_WP_Config
 */
function display_header() {
	header( 'Content-Type: text/html; charset=utf-8' );
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<meta http-equiv="Content-Type" content="text/html; charset=utf-8" />
<title>WordPress-a &rsaquo; agordodosiero</title>
<link rel="stylesheet" href="css/install.css" type="text/css" />

</head>
<body>
<h1 id="logo"><img alt="WordPress" src="images/wordpress-logo.png" /></h1>
<?php
}//end function display_header();

switch($step) {
	case 0:
		display_header();
?>

<p>Bonvenon ĉe WordPress. Unue, ni bezonas informojn pri la datumbazo. Vi bezonas scii la sekvajn erojn antaŭ ol ni daŭrigas</p>
<ol>
	<li>Nomo de datumbazo</li>
	<li>Uzantnomo por datumbazo</li>
	<li>Pasvorto por datumbazo</li>
	<li>Gastiganto de datumbazo</li>
	<li>Tabela prefikso (se vi volas havi pli ol unu WordPress en unu datumbazo) </li>
</ol>
<p><strong>Se por iu kialo tiu ĉi aŭtomata dosiera kreado misas, ne ĉagreniĝu. Temas pri la plenigo de informoj pri la datumbazo en agorda dosiero, kaj vi povas fari tion mane. Malfermu <code>wp-config-sample.php</code> en tekstoredaktilo, entajpu la informojn, kaj konservi ĝin kiel <code>wp-config.php</code>. </strong></p>
<p>Plej verŝajne, tiuj ĉi informoj estis donitaj al vi de via reta gastiganto. Se vi ne havas la informojn, vi bezonos kontakti ilin antaŭ ol vi povas daŭrigi. Se vi estas preta&hellip;</p>
<p class="step"><a href="setup-config.php?step=1<?php if ( isset( $_GET['noapi'] ) ) echo '&amp;noapi'; ?>" class="button">Ek!</a></p>
<?php
	break;

	case 1:
		display_header();
	?>
<form method="post" action="setup-config.php?step=2">
	<p>Sube, entajpu la detalojn pri via datumbazo. Se vi ne estas certa pri io, bonvolu kontakti vian gastiganton. </p>
	<table class="form-table">
		<tr>
			<th scope="row"><label for="dbname">Datumbaza nomo</label></th>
			<td><input name="dbname" id="dbname" type="text" size="25" value="wordpress" /></td>
			<td>La nomo de la datumbazo kiun vi volas utiligi por WP. </td>
		</tr>
		<tr>
			<th scope="row"><label for="uname">Uzantnomo</label></th>
			<td><input name="uname" id="uname" type="text" size="25" value="username" /></td>
			<td>Via uzantnomo por MySQL</td>
		</tr>
		<tr>
			<th scope="row"><label for="pwd">Pasvorto</label></th>
			<td><input name="pwd" id="pwd" type="text" size="25" value="password" /></td>
			<td>...kaj pasvorto por MySQL.</td>
		</tr>
		<tr>
			<th scope="row"><label for="dbhost">Datumbaza gastiganto</label></th>
			<td><input name="dbhost" id="dbhost" type="text" size="25" value="localhost" /></td>
			<td>Vi povas peti la informojn de via gastiganto, se <code>localhost</code> ne funkcias.</td>
		</tr>
		<tr>
			<th scope="row"><label for="prefix">Tabela prefikso</label></th>
			<td><input name="prefix" id="prefix" type="text" id="prefix" value="wp_" size="25" /></td>
			<td>Se vi volas ke Pli ol unu instalo de WordPress uzu nur unu datumbazon, ŝanĝu ĉi tion.</td>
		</tr>
	</table>
	<?php if ( isset( $_GET['noapi'] ) ) { ?><input name="noapi" type="hidden" value="true" /><?php } ?>
	<p class="step"><input name="submit" type="submit" value="Submit" class="button" /></p>
</form>
<?php
	break;

	case 2:
	$dbname  = trim($_POST['dbname']);
	$uname   = trim($_POST['uname']);
	$passwrd = trim($_POST['pwd']);
	$dbhost  = trim($_POST['dbhost']);
	$prefix  = trim($_POST['prefix']);
	if ( empty($prefix) )
		$prefix = 'wp_';

	// Validate $prefix: it can only contain letters, numbers and underscores
	if ( preg_match( '|[^a-z0-9_]|i', $prefix ) )
		wp_die( /*WP_I18N_BAD_PREFIX*/'<strong>ERARO</strong>: "Tabela prefikso" povas enhavi nur ciferojn, literojn kaj substrekojn.'/*/WP_I18N_BAD_PREFIX*/ );

	// Test the db connection.
	/**#@+
	 * @ignore
	 */
	define('DB_NAME', $dbname);
	define('DB_USER', $uname);
	define('DB_PASSWORD', $passwrd);
	define('DB_HOST', $dbhost);
	/**#@-*/

	// We'll fail here if the values are no good.
	require_wp_db();
	if ( ! empty( $wpdb->error ) ) {
		$back = '<p class="step"><a href="setup-config.php?step=1" onclick="javascript:history.go(-1);return false;" class="button">Provu denove</a></p>';
		wp_die( $wpdb->error->get_error_message() . $back );
	}

	// Fetch or generate keys and salts.
	$no_api = isset( $_POST['noapi'] );
	require_once( ABSPATH . WPINC . '/plugin.php' );
	require_once( ABSPATH . WPINC . '/l10n.php' );
	require_once( ABSPATH . WPINC . '/pomo/translations.php' );
	if ( ! $no_api ) {
		require_once( ABSPATH . WPINC . '/class-http.php' );
		require_once( ABSPATH . WPINC . '/http.php' );
		wp_fix_server_vars();
		/**#@+
		 * @ignore
		 */
		function get_bloginfo() {
			return ( ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . str_replace( $_SERVER['PHP_SELF'], '/wp-admin/setup-config.php', '' ) );
		}
		/**#@-*/
		$secret_keys = wp_remote_get( 'https://api.wordpress.org/secret-key/1.1/salt/' );
	}

	if ( $no_api || is_wp_error( $secret_keys ) ) {
		$secret_keys = array();
		require_once( ABSPATH . WPINC . '/pluggable.php' );
		for ( $i = 0; $i < 8; $i++ ) {
			$secret_keys[] = wp_generate_password( 64, true, true );
		}
	} else {
		$secret_keys = explode( "\n", wp_remote_retrieve_body( $secret_keys ) );
		foreach ( $secret_keys as $k => $v ) {
			$secret_keys[$k] = substr( $v, 28, 64 );
		}
	}
	$key = 0;

	foreach ($configFile as $line_num => $line) {
		switch (substr($line,0,16)) {
			case "define('DB_NAME'":
				$configFile[$line_num] = str_replace("database_name_here", $dbname, $line);
				break;
			case "define('DB_USER'":
				$configFile[$line_num] = str_replace("'username_here'", "'$uname'", $line);
				break;
			case "define('DB_PASSW":
				$configFile[$line_num] = str_replace("'password_here'", "'$passwrd'", $line);
				break;
			case "define('DB_HOST'":
				$configFile[$line_num] = str_replace("localhost", $dbhost, $line);
				break;
			case '$table_prefix  =':
				$configFile[$line_num] = str_replace('wp_', $prefix, $line);
				break;
			case "define('AUTH_KEY":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_KE":
			case "define('AUTH_SAL":
			case "define('SECURE_A":
			case "define('LOGGED_I":
			case "define('NONCE_SA":
				$configFile[$line_num] = str_replace('entajpu vian unikan frazon ĉi tie', $secret_keys[$key++], $line );
				break;
		}
	}
	if ( ! is_writable(ABSPATH) ) :
		display_header();
?>
<p>Bedaŭrinde, mi ne povas skribi la dosieron<code>wp-config.php</code>.</p>
<p>Vi povas mane krei <code>wp-config.php</code> kaj kopii la sekvan tekston en ĝin.</p>
<textarea cols="98" rows="15" class="code"><?php
		foreach( $configFile as $line ) {
			echo htmlentities($line, ENT_COMPAT, 'UTF-8');
		}
?></textarea>
<p>Poste, alklaku la butonon "Lanĉi la instalon."</p>
<p class="step"><a href="install.php" class="button">Lanĉi la instalon</a></p>
<?php
	else :
		$handle = fopen(ABSPATH . 'wp-config.php', 'w');
		foreach( $configFile as $line ) {
			fwrite($handle, $line);
		}
		fclose($handle);
		chmod(ABSPATH . 'wp-config.php', 0666);
		display_header();
?>
<p>Bonege, amiko! Vi venkis tiun parton de la instalo. WordPress povas komuniki kun via datumbazo. Se vi estas preta, ek al&hellip;</p>

<p class="step"><a href="install.php" class="button">Lanĉi la instalon</a></p>
<?php
	endif;
	break;
}
?>
</body>
</html>
